#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-uaUBmIZvtDL29Dw46FJWJ
key:                  gitit-0.15.1.2-uaUBmIZvtDL29Dw46FJWJ
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  253bcc2a38c2f038aff168254c6c8383
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-uaUBmIZvtDL29Dw46FJWJ
depends:
    HStringTemplate-0.8.8-L0EIVzgQXWU8mcjbKR6Xh8
    HTTP-4000.4.1-3VukQNL1PCCExje9qTwVXF
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.1.0-CAI92PkToAUJ8bQ51mPxny base-4.18.2.1
    base64-bytestring-1.2.1.0-Dq4HcYHUDsPZlT5wD319
    blaze-html-0.9.2.0-E6ZwQmdMquiBscNKuPUX8V bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-J21EataUmwj7q3ihbbyBAy
    feed-1.3.2.1-9ZPY1vSRzeb2AwPWHO0toQ filepath-1.4.300.1
    filestore-0.6.5.1-K3GlkR3nAG8H6vBsH1wJWc ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-J94VSxRlfXwFVA2bTbucLV
    hoauth2-2.14.0-HQEIh7sHvZH6WcGXIfzqX7
    hslogger-1.3.2.0-47fHfyvDLFhFFQ3m4a1hNt
    http-client-tls-0.3.6.4-AwjMi5EPjecJwO4HdPj3z6
    http-conduit-2.3.9.1-2r4pRMu4ptd3PSGJXKXh0
    json-0.10-Ix3cJnfMrt84nrYZAgyGJ mtl-2.3.1
    network-3.1.4.0-9EDRJJtHW1KCcUSE16S97f
    network-bsd-2.8.1.0-1Z7AncuDjyt2jnekxOGoJf
    network-uri-2.6.4.2-CUPIiFyjgc04bf0n9Rn9SQ
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG
    pandoc-3.6-8U7e2WmrcMqeEeyjIvsUL
    pandoc-types-1.23.1-2Pek0JkhxRDKVh1nopIvid parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-8xCOAhjQqZaHKyZvNvQjlZ
    recaptcha-0.1.0.4-Lt9rkyOopeA39B9Wq3tZBx
    safe-0.3.21-2UXksValeRA7gt4jf0mLYg
    skylighting-0.14.4-JBFVfJGZWOF7R9PUJlrvmd
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-GhxEKVO9aRZHddME5iK0hL
    tagsoup-0.14.8-KAMVmaO42qp1PNPcuBRY3z
    temporary-1.3-3Uec348YK1vIAXQsp8Wva5 text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-5MfqgR8KtThKs9YykA7YE6
    url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    uuid-1.3.16-rkTYpdguxhwc6ZExE3D9 xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-BHXCleyUzpZLTvMUWevRIg
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-KN83mQNRDFrIO1QMBEmDGr
    zlib-0.7.0.0-7a4n9ufRZXp4mpeaigMhcq

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

